@@ -1,8 +1,6 @@
 use crate::format::coord_index::CoordIndex;
 use crate::format::problem::reader::{parse_time_window, ApiProblem, ProblemProperties};
-use crate::format::problem::{
-    JobTask, RelationType, VehicleBreak, VehicleBreakTime, VehicleDispatch, VehicleReload, VehicleType,
-};
+use crate::format::problem::*;
 use crate::format::{JobIndex, Location};
 use crate::utils::VariableJobPermutation;
 use std::sync::Arc;
@@ -11,7 +9,7 @@ use vrp_core::models::problem::{Actor, Fleet, Job, Jobs, Multi, Place, Single, T
 use vrp_core::models::{Lock, LockDetail, LockOrder, LockPosition};
 use vrp_core::utils::{compare_floats, Random};
 
-use crate::constraints::JobSkills as ConstraintJobSkills;
+use crate::constraints::{BreakPolicy, JobSkills as ConstraintJobSkills};
 use crate::format::problem::JobSkills as FormatJobSkills;
 use crate::parse_time;
 use hashbrown::HashMap;
@@ -162,9 +160,10 @@ fn read_required_jobs(
         assert!(!singles.is_empty());
 
         let problem_job = if singles.len() > 1 {
-            get_multi_job(&job.id, &job.skills, job.value, singles, job.pickups.as_ref().map_or(0, |p| p.len()), random)
+            let deliveries_start_index = job.pickups.as_ref().map_or(0, |p| p.len());
+            get_multi_job(&job.id, &job.skills, job.value, &job.group, singles, deliveries_start_index, random)
         } else {
-            get_single_job(&job.id, singles.into_iter().next().unwrap(), &job.skills, job.value)
+            get_single_job(&job.id, singles.into_iter().next().unwrap(), &job.skills, job.value, &job.group)
         };
 
         job_index.insert(job.id.clone(), problem_job.clone());
@@ -235,9 +234,18 @@ fn read_breaks(
                         .map(|place| (place.location.clone(), place.duration, times.clone(), place.tag.clone()))
                         .collect();
 
-                    let job =
+                    let mut job =
                         get_conditional_job(coord_index, vehicle_id.clone(), &job_id, "break", shift_index, places);
 
+                    if let Some(policy) = &vehicle_break.policy {
+                        let policy = match policy {
+                            VehicleBreakPolicy::SkipIfNoIntersection => BreakPolicy::SkipIfNoIntersection,
+                            VehicleBreakPolicy::SkipIfArrivalBeforeEnd => BreakPolicy::SkipIfArrivalBeforeEnd,
+                        };
+
+                        job.dimens.set_value("policy", policy);
+                    }
+
                     (job_id, job)
                 })
                 .collect::<Vec<_>>()
@@ -394,11 +402,18 @@ fn get_single_with_extras(
     single
 }
 
-fn get_single_job(id: &str, single: Single, skills: &Option<FormatJobSkills>, value: Option<f64>) -> Job {
+fn get_single_job(
+    id: &str,
+    single: Single,
+    skills: &Option<FormatJobSkills>,
+    value: Option<f64>,
+    group: &Option<String>,
+) -> Job {
     let mut single = single;
     single.dimens.set_id(id);
 
     add_value(&mut single.dimens, value);
+    add_group(&mut single.dimens, group);
     add_job_skills(&mut single.dimens, skills);
 
     Job::Single(Arc::new(single))
@@ -408,6 +423,7 @@ fn get_multi_job(
     id: &str,
     skills: &Option<FormatJobSkills>,
     value: Option<f64>,
+    group: &Option<String>,
     singles: Vec<Single>,
     deliveries_start_index: usize,
     random: &Arc<dyn Random + Send + Sync>,
@@ -415,6 +431,7 @@ fn get_multi_job(
     let mut dimens: Dimensions = Default::default();
     dimens.set_id(id);
     add_value(&mut dimens, value);
+    add_group(&mut dimens, group);
     add_job_skills(&mut dimens, skills);
 
     let singles = singles.into_iter().map(Arc::new).collect::<Vec<_>>();
@@ -463,6 +480,12 @@ fn add_value(dimens: &mut Dimensions, value: Option<f64>) {
     }
 }
 
+fn add_group(dimens: &mut Dimensions, group: &Option<String>) {
+    if let Some(group) = group {
+        dimens.set_value("group", group.clone());
+    }
+}
+
 fn add_job_skills(dimens: &mut Dimensions, skills: &Option<FormatJobSkills>) {
     if let Some(skills) = skills {
         dimens.set_value(
