@@ -427,12 +427,13 @@ pub enum Objective {
     #[serde(rename(deserialize = "maximize-value", serialize = "maximize-value"))]
     MaximizeValue {
         /// Specifies a weight of skipped breaks. Default value is 100.
-        #[serde(rename = "camelCase")]
+        #[serde(skip_serializing_if = "Option::is_none")]
         breaks: Option<f64>,
 
         /// A factor to reduce value cost compared to max cost.
         /// Default value is 0.1.
-        #[serde(rename = "camelCase")]
+        #[serde(rename = "reductionFactor")]
+        #[serde(skip_serializing_if = "Option::is_none")]
         reduction_factor: Option<f64>,
     },
 
@@ -481,9 +482,10 @@ pub enum Objective {
     },
 
     /// An objective to control order of job activities in the tour.
-    #[serde(rename(deserialize = "balance-duration", serialize = "tour-order"))]
+    #[serde(rename(deserialize = "tour-order", serialize = "tour-order"))]
     TourOrder {
         /// If the proper is set to true, then order is enforced as hard constraint.
+        #[serde(rename = "isConstrained")]
         is_constrained: bool,
     },
 }
