@@ -6,31 +6,114 @@ use super::Solution;
 use crate::format::solution::{Stop, Tour, UnassignedJob};
 use crate::format::{get_coord_index, get_job_index, CoordIndex, Location};
 use serde::Serialize;
+use std::cmp::Ordering;
 use std::collections::HashMap;
 use std::io::{BufWriter, Error, ErrorKind, Write};
-use vrp_core::models::problem::{Job, Place};
+use vrp_core::models::problem::Job;
 use vrp_core::models::Problem;
+use vrp_core::utils::compare_floats;
 
-#[derive(Clone, Serialize, Debug)]
+#[derive(Clone, Debug, Serialize)]
 #[serde(tag = "type")]
 enum Geometry {
     Point { coordinates: (f64, f64) },
     LineString { coordinates: Vec<(f64, f64)> },
 }
 
-#[derive(Clone, Serialize, Debug)]
+#[derive(Clone, Debug, Serialize)]
 #[serde(tag = "type")]
 struct Feature {
     pub properties: HashMap<String, String>,
     pub geometry: Geometry,
 }
 
-#[derive(Clone, Serialize, Debug)]
+#[derive(Clone, Debug, Serialize, Eq, PartialEq)]
 #[serde(tag = "type")]
 struct FeatureCollection {
     pub features: Vec<Feature>,
 }
 
+impl Eq for Geometry {}
+
+impl PartialEq for Geometry {
+    fn eq(&self, other: &Self) -> bool {
+        let compare_pair = |l_coord: &(f64, f64), r_coord: &(f64, f64)| {
+            compare_floats(l_coord.0, r_coord.0) == Ordering::Equal
+                && compare_floats(l_coord.1, r_coord.1) == Ordering::Equal
+        };
+
+        match (self, other) {
+            (Geometry::Point { coordinates: l_coord }, Geometry::Point { coordinates: r_coord }) => {
+                compare_pair(l_coord, r_coord)
+            }
+            (Geometry::LineString { coordinates: l_coords }, Geometry::LineString { coordinates: r_coords }) => {
+                l_coords.len() == r_coords.len()
+                    && l_coords.iter().zip(r_coords.iter()).all(|(l_coord, r_coord)| compare_pair(l_coord, r_coord))
+            }
+            _ => false,
+        }
+    }
+}
+
+impl Eq for Feature {}
+
+impl PartialEq for Feature {
+    fn eq(&self, other: &Self) -> bool {
+        let same_properties = self.properties.len() == other.properties.len()
+            && self.properties.keys().all(|key| {
+                if let Some(value) = other.properties.get(key) {
+                    self.properties[key] == *value
+                } else {
+                    false
+                }
+            });
+
+        same_properties && self.geometry.eq(&other.geometry)
+    }
+}
+
+/// Serializes solution into geo json format.
+pub fn serialize_solution_as_geojson<W: Write>(
+    writer: BufWriter<W>,
+    problem: &Problem,
+    solution: &Solution,
+) -> Result<(), Error> {
+    let geo_json = create_geojson_solution(problem, solution)?;
+
+    serde_json::to_writer_pretty(writer, &geo_json).map_err(Error::from)
+}
+
+/// Serializes named location list with their color index.
+pub fn serialize_named_locations_as_geojson<W: Write>(
+    writer: BufWriter<W>,
+    locations: &[(String, Location, usize)],
+) -> Result<(), Error> {
+    let geo_json = create_geojson_named_locations(locations)?;
+
+    serde_json::to_writer_pretty(writer, &geo_json).map_err(Error::from)
+}
+
+fn create_geojson_named_locations(locations: &[(String, Location, usize)]) -> Result<FeatureCollection, Error> {
+    let colors = get_more_colors();
+
+    Ok(FeatureCollection {
+        features: locations
+            .iter()
+            .map(|(name, location, index)| {
+                Ok(Feature {
+                    properties: slice_to_map(&[
+                        ("marker-color", colors[*index % colors.len()]),
+                        ("marker-size", "medium"),
+                        ("marker-symbol", "marker"),
+                        ("name", name),
+                    ]),
+                    geometry: Geometry::Point { coordinates: get_lng_lat(location)? },
+                })
+            })
+            .collect::<Result<Vec<_>, Error>>()?,
+    })
+}
+
 fn slice_to_map(vec: &[(&str, &str)]) -> HashMap<String, String> {
     vec.iter().map(|&(key, value)| (key.to_string(), value.to_string())).collect()
 }
@@ -71,12 +154,7 @@ fn get_unassigned_points(
     job: &Job,
     color: &str,
 ) -> Result<Vec<Feature>, Error> {
-    let places: Box<dyn Iterator<Item = &Place>> = match job {
-        Job::Single(single) => Box::new(single.places.iter()),
-        Job::Multi(multi) => Box::new(multi.jobs.iter().flat_map(|single| single.places.iter())),
-    };
-
-    places
+    job.places()
         .filter_map(|place| place.location.and_then(|l| coord_index.get_by_idx(l)))
         .map(|location| {
             let coordinates = get_lng_lat(&location)?;
@@ -165,17 +243,6 @@ fn create_geojson_solution(problem: &Problem, solution: &Solution) -> Result<Fea
     })
 }
 
-/// Serializes solution into geo json format.
-pub fn serialize_solution_as_geojson<W: Write>(
-    writer: BufWriter<W>,
-    problem: &Problem,
-    solution: &Solution,
-) -> Result<(), Error> {
-    let geo_json = create_geojson_solution(problem, solution)?;
-
-    serde_json::to_writer_pretty(writer, &geo_json).map_err(Error::from)
-}
-
 fn get_color(idx: usize) -> String {
     static COLOR_LIST: ColorList = get_color_list();
 
@@ -210,3 +277,24 @@ const fn get_color_list() -> ColorList {
         "#9a6324", "#800000", "#808000", "#000075", "#808080",
     ]
 }
+
+type MoreColorList = &'static [&'static str; 128];
+
+/// Returns more colors.
+const fn get_more_colors() -> MoreColorList {
+    &[
+        "#000000", "#FFFF00", "#1CE6FF", "#FF34FF", "#FF4A46", "#008941", "#006FA6", "#A30059", "#FFDBE5", "#7A4900",
+        "#0000A6", "#63FFAC", "#B79762", "#004D43", "#8FB0FF", "#997D87", "#5A0007", "#809693", "#FEFFE6", "#1B4400",
+        "#4FC601", "#3B5DFF", "#4A3B53", "#FF2F80", "#61615A", "#BA0900", "#6B7900", "#00C2A0", "#FFAA92", "#FF90C9",
+        "#B903AA", "#D16100", "#DDEFFF", "#000035", "#7B4F4B", "#A1C299", "#300018", "#0AA6D8", "#013349", "#00846F",
+        "#372101", "#FFB500", "#C2FFED", "#A079BF", "#CC0744", "#C0B9B2", "#C2FF99", "#001E09", "#00489C", "#6F0062",
+        "#0CBD66", "#EEC3FF", "#456D75", "#B77B68", "#7A87A1", "#788D66", "#885578", "#FAD09F", "#FF8A9A", "#D157A0",
+        "#BEC459", "#456648", "#0086ED", "#886F4C", "#34362D", "#B4A8BD", "#00A6AA", "#452C2C", "#636375", "#A3C8C9",
+        "#FF913F", "#938A81", "#575329", "#00FECF", "#B05B6F", "#8CD0FF", "#3B9700", "#04F757", "#C8A1A1", "#1E6E00",
+        "#7900D7", "#A77500", "#6367A9", "#A05837", "#6B002C", "#772600", "#D790FF", "#9B9700", "#549E79", "#FFF69F",
+        "#201625", "#72418F", "#BC23FF", "#99ADC0", "#3A2465", "#922329", "#5B4534", "#FDE8DC", "#404E55", "#0089A3",
+        "#CB7E98", "#A4E804", "#324E72", "#6A3A4C", "#83AB58", "#001C1E", "#D1F7CE", "#004B28", "#C8D0F6", "#A3A489",
+        "#806C66", "#222800", "#BF5650", "#E83000", "#66796D", "#DA007C", "#FF1A59", "#8ADBB4", "#1E0200", "#5B4E51",
+        "#C895C5", "#320033", "#FF6832", "#66E1D3", "#CFCDAC", "#D0AC94", "#7ED379", "#012C58",
+    ]
+}
