@@ -2,5 +2,5 @@ mod basic_break_test;
 mod break_with_multiple_locations;
 mod interval_break_test;
 mod multi_break_test;
+mod policy_break_test;
 mod relation_break_test;
-mod skip_break_test;
